self.__BUILD_MANIFEST=function(s,t,a,e){return{__rewrites:{beforeFiles:[],afterFiles:[{source:"/CLOUD_NOTEBOOK_BASE_PATH_PLACEHOLDER_/datasets",destination:s},{source:"/CLOUD_NOTEBOOK_BASE_PATH_PLACEHOLDER_",destination:s}],fallback:[]},"/":["static/chunks/pages/index-61cbbf5ce82ed730.js"],"/_error":["static/chunks/pages/_error-6e9e91b82ad4472f.js"],"/datasets":[t,a,e,"static/chunks/pages/datasets-8033070088b6a4e0.js"],"/datasets/[...slug]":["static/chunks/29107295-f7ca5de7ec07893d.js","static/chunks/8a28b14e-390be93601992c10.js",t,a,"static/chunks/1830-d10560d53ce4ed5b.js",e,"static/chunks/pages/datasets/[...slug]-4e1b705c599c95bc.js"],"/test":[t,"static/chunks/pages/test-88162cd434c20079.js"],sortedPages:["/","/_app","/_error",s,"/datasets/[...slug]","/test"]}}("/datasets","static/chunks/2895-d892d4e67e90391e.js","static/chunks/3183-081faf44d7e80e13.js","static/chunks/7838-31c9029618547a94.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();