(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5405],{6282:function(n,t,u){n.exports=u(5575)},3878:function(n,t,u){"use strict";u.r(t);var e=u(6282),s=u.n(e),a=u(2771);t.default=function(){var n=(0,e.useRouter)(),t=n.query,u=n.asPath.split("?")[0],c="/datasets";u&&"/"!==u&&(c=u.includes("/datasets")?u:"".concat(u,"/datasets")),(0,a.useEffect)((function(){s().push({pathname:c,query:t})}),[])}},8312:function(n,t,u){(window.__NEXT_P=window.__NEXT_P||[]).push(["/",function(){return u(3878)}])}},function(n){n.O(0,[9774,2888,179],(function(){return t=8312,n(n.s=t);var t}));var t=n.O();_N_E=t}]);