(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9671],{105:function(e,n,t){"use strict";t.r(n),t.d(n,{default:function(){return W}});var r=t(6282),i=t.n(r),l=t(7971),a=t(9955),d=t(919),o=t(4201),s=t(1754),c=t(6673),u=t(3506),h=t.n(u);function f(e){return e.children}f.propTypes={afterChildren:h().node,beforeChildren:h().node,children:h().node.isRequired,disabled:h().bool,label:h().string.isRequired};var b=t(2771),x=t(7996),m=t(3461),p=t(9711),j=t(1969),v=t(2005),g=t(9125),y=t(3942),C=t(6436),Z=x.default.div.withConfig({displayName:"Tabs__TabHeaderContainerStyle",componentId:"sc-rojme5-0"})(["",""],(function(e){return e.containerWidthPercentage&&"\n    width: ".concat(e.containerWidthPercentage,"%;\n  ")})),_=x.default.div.withConfig({displayName:"Tabs__TabHeader",componentId:"sc-rojme5-1"})(["border-top-left-radius:","px;border-top-right-radius:","px;margin-right:","px;position:relative;z-index:2;"," "," ",""],y.BG,y.BG,6*g.iI,(function(e){return e.noBottomBorder&&"\n    border-bottom: none;\n  "}),(function(e){return e.active&&"\n    border-bottom: ".concat(g.cd,"px solid;\n    border-color: ").concat((e.theme.interactive||j.Z.interactive).linkPrimary,";\n  ")}),(function(e){return e.fullWidth&&"\n    width: 100%;\n  "})),k=x.default.div.withConfig({displayName:"Tabs__LinkStyle",componentId:"sc-rojme5-2"})(["align-items:center;display:flex;"," "," ",""],(function(e){return e.bold&&"\n    font-family: ".concat(v.nF,";\n  ")}),(function(e){return e.fullWidth&&"\n    justify-content: center;\n  "}),(function(e){return!e.disabled&&"\n    &:hover {\n      path {\n        fill: ".concat((e.theme.content||j.Z.interactive).linkPrimary," !important;\n      }\n    }\n  ")}));var P=function(e){var n=e.actionEl,t=e.bold,r=e.children,i=e.containerWidthPercentage,a=e.currentTab,o=e.defaultKey,s=e.fullWidth,u=e.large,h=e.noBottomBorder,f=e.onChange,x=Array.isArray(r)?r.filter((function(e){return!!e})):[r],j=b.Children.map(x,(function(e){return e.key})),v=(0,b.useState)(o||j[0]),y=v[0],P=v[1],T=a||y;return(0,b.useEffect)((function(){P(o)}),[o]),(0,C.jsxs)(C.Fragment,{children:[(0,C.jsx)(Z,{containerWidthPercentage:i,children:(0,C.jsxs)(l.Z,{justifyContent:s?"center":null,children:[n&&(0,C.jsx)(m.Z,{flex:"1",children:n}),b.Children.map(x,(function(e){var n=e.key,r=e.props,i=T===n,l={default:!i,disabled:r.disabled,size:2*g.iI};return(0,C.jsx)(m.Z,{flex:s?"1":null,children:(0,C.jsx)(d.Z,{block:!0,default:!i,disabled:r.disabled,flex:1,large:u,noHoverUnderline:!0,noOutline:!0,onClick:function(){f&&f(n),P(n)},preventDefault:!0,sameColorAsText:i,children:(0,C.jsx)(_,{active:i,fullWidth:s,noBottomBorder:h,children:(0,C.jsxs)(k,{bold:t&&i,disabled:r.disabled,fullWidth:s,large:u,children:[r.beforeChildren&&b.cloneElement(r.beforeChildren,l),(0,C.jsx)(c.Z,{ml:r.beforeChildren?1:0,mr:r.afterChildren?1:0,children:(0,C.jsx)(p.ZP,{bold:t,large:u,children:r.label})}),r.afterChildren&&b.cloneElement(r.afterChildren,l)]})})})},n)}))]})}),x.filter((function(e){return e.key===T}))]})},T=t(79),w=t(512),N=t(9345),B=t(254),E=t(8183),W=function(){var e=T.ZP.feature_sets.list().data,n=e?(0,E.YC)(e,(function(e){return e.id}),{ascending:!1}):[];return(0,C.jsx)(a.Z,{centerAlign:!0,header:(0,C.jsx)(c.Z,{mt:g.iI}),pageTitle:"Dataset Dashboard",children:(0,C.jsx)(c.Z,{px:1,children:(0,C.jsx)(P,{bold:!0,defaultKey:"datasets",large:!0,children:(0,C.jsx)(f,{label:"Datasets",children:(0,C.jsx)(c.Z,{pb:3,pt:3,children:(0,C.jsx)(s.Z,{headerDetails:(0,B._6)("dataset",null===n||void 0===n?void 0:n.length),headerTitle:"datasets",children:(null===n||void 0===n?void 0:n.length)>0?null===n||void 0===n?void 0:n.map((function(e,t){var r=e||{},a=r.id,s=r.metadata||{},u=s.column_types,h=void 0===u?{}:u,f=s.name,b=void 0===f?"dataset_".concat(a):f,x=s.statistics||{},m=x.count,j=x.quality,v=h?Object.keys(h).length:0;return(0,C.jsxs)(o.Z,{columnFlexNumbers:[4,1,1,1],last:t===n.length-1,children:[(0,C.jsxs)(l.Z,{alignItems:"center",children:[(0,C.jsx)(w.$B,{secondary:!0}),(0,C.jsx)(c.Z,{mr:1}),(0,C.jsx)(d.Z,{noHoverUnderline:!0,onClick:function(){return i().push("datasets/".concat(a))},preventDefault:!0,sameColorAsText:!0,children:b})]}),(0,C.jsxs)(p.ZP,{children:[(0,B.x6)(v)," features"]}),(0,C.jsxs)(p.ZP,{children:[(0,B.x6)(m)," rows"]}),(0,C.jsx)(p.ZP,{bold:(0,N.FH)(j),danger:(0,N.FH)(j),children:j})]},a)})):(0,C.jsx)(c.Z,{p:2,children:(0,C.jsx)(p.ZP,{children:"No datasets available. Add one to get started."})})})})},"datasets")})})})}},1246:function(e,n,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/datasets",function(){return t(105)}])}},function(e){e.O(0,[2895,3183,7838,9774,2888,179],(function(){return n=1246,e(e.s=n);var n}));var n=e.O();_N_E=n}]);